## Description
Brief description of the changes.

## Type of Change
- [ ] Bug fix (non-breaking change which fixes an issue)
- [ ] New feature (non-breaking change which adds functionality)
- [ ] Breaking change (fix or feature that would cause existing functionality to not work as expected)
- [ ] Documentation update

## Related Issues
Fixes #<issue_number> (if applicable)

## Checklist
- [ ] Tests pass locally (`pytest`)
- [ ] New tests added for new functionality
- [ ] Code follows project style guidelines
- [ ] Comments added for complex code
- [ ] Documentation updated (if applicable)
- [ ] No new warnings generated
- [ ] Conventional commit format used
- [ ] Pre-commit ran on all modified files
